.. _gwpy-reference:

#############
API Reference
#############

Complete reference documentation for all GWpy classes, functions, and modules.

.. admonition:: 🔍 Looking for something specific?
    :class: tip

    - **New to GWpy?** Start with :doc:`/getting-started`
    - **Learning by example?** Browse :doc:`/examples/index`

----

.. toctree::
    :maxdepth: 2
    :caption: GWpy API Reference

    gwpy.astro
    gwpy.detector
    gwpy.frequencyseries
    gwpy.io
    gwpy.log
    gwpy.plot
    gwpy.segments
    gwpy.signal
    gwpy.spectrogram
    gwpy.table
    gwpy.time
    gwpy.timeseries
    gwpy.types
    gwpy.utils
